"use client"

import Link from "next/link"
import Image from "next/image"
import { useState } from "react"
import { Menu, X, ChevronDown, User, LogOut } from "lucide-react"
import { chapters } from "@/data/chapters"
import { useAuth } from "@/context/auth-context"
import { generateSlug } from "@/utils/slug-utils"

export default function Header() {
  const { user, logout } = useAuth()
  const [isMenuOpen, setIsMenuOpen] = useState(false)
  const [openDropdown, setOpenDropdown] = useState<string | null>(null)

  const toggleDropdown = (chapter: string) => {
    if (openDropdown === chapter) {
      setOpenDropdown(null)
    } else {
      setOpenDropdown(chapter)
    }
  }

  return (
    <header className="bg-white shadow-md sticky top-0 z-50">
      <div className="container mx-auto px-4">
        <div className="flex justify-between items-center h-16">
          <Link href="/" className="flex items-center">
            <Image src="/logo.svg" alt="Code de la Route" width={150} height={40} priority />
          </Link>

          {/* Navigation desktop */}
          <nav className="hidden md:flex items-center space-x-6">
            <Link href="/" className="text-gray-700 hover:text-[#3d53b6]">
              Accueil
            </Link>

            <div className="relative group">
              <div className="flex items-center">
                <Link href="/chapitres" className="text-gray-700 hover:text-[#3d53b6] mr-1">
                  Chapitres
                </Link>
                <button
                  className="flex items-center text-gray-700 hover:text-[#3d53b6]"
                  onClick={() => toggleDropdown("chapitres")}
                >
                  <ChevronDown className="h-4 w-4" />
                </button>
              </div>

              <div
                className={`absolute left-0 mt-2 w-64 bg-white rounded-md shadow-lg overflow-hidden transition-all duration-300 ${openDropdown === "chapitres" ? "opacity-100 scale-100" : "opacity-0 scale-95 pointer-events-none"}`}
              >
                <div className="py-2">
                  {chapters.map((chapter) => {
                    const chapterTitle = chapter.chapter.split(". ")[1]
                    const chapterSlug = generateSlug(chapterTitle)
                    return (
                      <Link
                        key={chapter.chapter}
                        href={`/chapitres/${chapterSlug}`}
                        className="block px-4 py-2 text-sm text-gray-700 hover:bg-[#1da7f3]/10"
                        onClick={() => setOpenDropdown(null)}
                      >
                        {chapter.chapter}
                      </Link>
                    )
                  })}
                </div>
              </div>
            </div>

            <Link href="/parcours" className="text-gray-700 hover:text-[#3d53b6]">
              Parcours
            </Link>

            <Link href="/perception-des-risques" className="text-gray-700 hover:text-[#3d53b6]">
              Perception des risques
            </Link>

            <Link href="/simulations" className="text-gray-700 hover:text-[#3d53b6]">
              Simulations
            </Link>

            <Link href="/examen" className="text-gray-700 hover:text-[#3d53b6]">
              Examen
            </Link>
          </nav>

          {/* User menu - desktop */}
          {user ? (
            <div className="hidden md:flex items-center space-x-4">
              <Link href="/profile" className="text-gray-700 hover:text-[#3d53b6] flex items-center">
                <User className="h-5 w-5 mr-1" />
                <span>{user.name}</span>
              </Link>
              <button onClick={logout} className="text-gray-700 hover:text-red-500 flex items-center">
                <LogOut className="h-5 w-5 mr-1" />
                <span>Déconnexion</span>
              </button>
            </div>
          ) : (
            <div className="hidden md:flex items-center space-x-4">
              <Link href="/auth/login" className="text-gray-700 hover:text-[#3d53b6]">
                Se connecter
              </Link>
              <Link
                href="/auth/register"
                className="bg-[#3d53b6] text-white px-4 py-2 rounded-md hover:bg-[#1da7f3] transition-colors"
              >
                S'inscrire
              </Link>
            </div>
          )}

          {/* Bouton menu mobile */}
          <button className="md:hidden text-gray-700" onClick={() => setIsMenuOpen(!isMenuOpen)}>
            {isMenuOpen ? <X className="h-6 w-6" /> : <Menu className="h-6 w-6" />}
          </button>
        </div>
      </div>

      {/* Menu mobile */}
      {isMenuOpen && (
        <div className="md:hidden bg-white border-t border-gray-100 py-2">
          <div className="container mx-auto px-4">
            <nav className="flex flex-col space-y-2">
              <Link href="/" className="py-2 text-gray-700 hover:text-[#3d53b6]" onClick={() => setIsMenuOpen(false)}>
                Accueil
              </Link>

              <div>
                <div className="flex items-center justify-between">
                  <Link
                    href="/chapitres"
                    className="py-2 text-gray-700 hover:text-[#3d53b6] flex-grow"
                    onClick={() => setIsMenuOpen(false)}
                  >
                    Chapitres
                  </Link>
                  <button
                    className="p-2 text-gray-700 hover:text-[#3d53b6]"
                    onClick={() => toggleDropdown("chapitres-mobile")}
                  >
                    <ChevronDown
                      className={`h-4 w-4 transition-transform ${openDropdown === "chapitres-mobile" ? "rotate-180" : ""}`}
                    />
                  </button>
                </div>

                {openDropdown === "chapitres-mobile" && (
                  <div className="pl-4 mt-1 border-l-2 border-[#1da7f3]/20">
                    {chapters.map((chapter) => {
                      const chapterTitle = chapter.chapter.split(". ")[1]
                      const chapterSlug = generateSlug(chapterTitle)
                      return (
                        <Link
                          key={chapter.chapter}
                          href={`/chapitres/${chapterSlug}`}
                          className="block py-2 text-gray-700 hover:text-[#3d53b6]"
                          onClick={() => {
                            setOpenDropdown(null)
                            setIsMenuOpen(false)
                          }}
                        >
                          {chapter.chapter}
                        </Link>
                      )
                    })}
                  </div>
                )}
              </div>

              <Link
                href="/parcours"
                className="py-2 text-gray-700 hover:text-[#3d53b6]"
                onClick={() => setIsMenuOpen(false)}
              >
                Parcours
              </Link>

              <Link
                href="/perception-des-risques"
                className="py-2 text-gray-700 hover:text-[#3d53b6]"
                onClick={() => setIsMenuOpen(false)}
              >
                Perception des risques
              </Link>

              <Link
                href="/simulations"
                className="py-2 text-gray-700 hover:text-[#3d53b6]"
                onClick={() => setIsMenuOpen(false)}
              >
                Simulations
              </Link>

              <Link
                href="/examen"
                className="py-2 text-gray-700 hover:text-[#3d53b6]"
                onClick={() => setIsMenuOpen(false)}
              >
                Examen
              </Link>

              {/* User menu - mobile */}
              {user ? (
                <>
                  <div className="border-t border-gray-200 my-2"></div>
                  <Link
                    href="/profile"
                    className="py-2 text-gray-700 hover:text-[#3d53b6] flex items-center"
                    onClick={() => setIsMenuOpen(false)}
                  >
                    <User className="h-5 w-5 mr-2" />
                    <span>Mon Profil</span>
                  </Link>
                  <button
                    onClick={() => {
                      logout()
                      setIsMenuOpen(false)
                    }}
                    className="py-2 text-gray-700 hover:text-red-500 flex items-center w-full text-left"
                  >
                    <LogOut className="h-5 w-5 mr-2" />
                    <span>Déconnexion</span>
                  </button>
                </>
              ) : (
                <>
                  <div className="border-t border-gray-200 my-2"></div>
                  <Link
                    href="/auth/login"
                    className="py-2 text-gray-700 hover:text-[#3d53b6] flex items-center"
                    onClick={() => setIsMenuOpen(false)}
                  >
                    <User className="h-5 w-5 mr-2" />
                    <span>Se connecter</span>
                  </Link>
                  <Link
                    href="/auth/register"
                    className="py-2 text-[#3d53b6] font-medium hover:text-[#1da7f3] flex items-center"
                    onClick={() => setIsMenuOpen(false)}
                  >
                    <span>S'inscrire</span>
                  </Link>
                </>
              )}
            </nav>
          </div>
        </div>
      )}
    </header>
  )
}
